==> appconsent_tv-0.1.4.tar.gz: android/src/main/kotlin/io/sfbx/appconsent_tv/AppconsentTvPlugin.kt <==
package io.sfbx.appconsent_tv

import android.app.Activity
import android.content.Context
import androidx.annotation.NonNull
import com.sfbx.appconsent.core.model.ConsentableType
import com.sfbx.appconsent.tv.AppConsentImpl
import com.sfbx.appconsent.tv.AppConsentTV
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** AppconsentTvPlugin */
class AppconsentTvPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {
    /// The MethodChannel that will handle the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel
    private lateinit var context: Context
    private lateinit var activity: Activity

    var ackit: AppConsentTV? = null

    override fun onDetachedFromActivity() {
        ackit = null
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
        ackit = null
    }

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "appconsent_tv")
        channel.setMethodCallHandler(this)
        context = flutterPluginBinding.applicationContext
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "setup" -> setup(call, result)
            "presentNotice" -> presentNotice(call, result)
            "clearConsent" -> clearConsent(result)
            "checkForUpdate" -> checkForUpdate(result)
            "isSubjectToGDPR" -> isSubjectToGDPR(result)
            "consentGiven" -> consentGiven(result)
            "geolocationConsentGiven" -> geolocationConsentGiven(result)
            "consentableAllowed" -> consentableAllowed(call, result)
            else -> {
                result.notImplemented()
            }
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    private fun setup(call: MethodCall, result: Result) {
        val appKey: String = call.argument("appKey") ?: ""
        val forceApplyGDPR: Boolean = call.argument("forceApplyGDPR") ?: false
        ackit = AppConsentTV(
            context = activity,
            appKey = appKey,
            forceApplyGDPR = forceApplyGDPR, onReady = { (this::onReady)(it, result) })
    }

    private fun onReady(appConsent: AppConsentImpl, result: Result) {
        result.success(null)
    }

    private fun presentNotice(call: MethodCall, result: Result) {
        val force: Boolean = call.argument("force") ?: false
        ackit!!.presentNotice(force)
        result.success(null)
    }

    private fun clearConsent(result: Result) {
        ackit!!.clearConsent()
        result.success(null)
    }

    private fun checkForUpdate(result: Result) {
        ackit!!.checkForUpdate(onResult = {
            result.success(it)
        },
            error = {
                result.success(false)
            })
    }

    private fun isSubjectToGDPR(result: Result) {
        val isSubjectToGDPR = ackit!!.isSubjectToGDPR()
        result.success(isSubjectToGDPR)
    }

    private fun consentGiven(result: Result) {
        val consentGiven = ackit!!.consentGiven()
        result.success(consentGiven)
    }

    private fun geolocationConsentGiven(result: Result) {
        val geolocationConsentGiven = ackit!!.geolocationConsentGiven()
        result.success(geolocationConsentGiven)
    }

    private fun consentableAllowed(call: MethodCall, result: Result) {
        val iabId: Int = call.argument("iabId") ?: 0
        val type: Int = call.argument("consentableType") ?: 0
        val consentableType: ConsentableType = when (type) {
            0 -> ConsentableType.PURPOSE
            1 -> ConsentableType.FEATURE
            2 -> ConsentableType.SPECIAL_FEATURE
            3 -> ConsentableType.SPECIAL_PURPOSE
            else -> ConsentableType.UNKNOWN
        }
        val isAllowed = ackit!!.consentableAllowed(iabId, consentableType)
        result.success(isAllowed)
    }
}

==> appconsent_tv-1.0.1.tar.gz: android/src/main/kotlin/io/sfbx/appconsent_tv/AppconsentTvPlugin.kt <==
package io.sfbx.appconsent_tv

import android.content.Context
import android.content.pm.PackageManager
import android.util.Log
import androidx.annotation.NonNull
import androidx.browser.customtabs.CustomTabsClient.getPackageName
import com.sfbx.appconsent.core.model.ConsentableType
import com.sfbx.appconsent.tv.AppConsentImpl
import com.sfbx.appconsent.tv.AppConsentTV
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

class AppconsentTvPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {
    private lateinit var channel: MethodChannel
    private var context: Context? = null
    private var ackit: AppConsentTV? = null

    override fun onDetachedFromActivity() {
        ackit = null
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {

    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {

    }

    override fun onDetachedFromActivityForConfigChanges() {
        ackit = null
    }

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, channelName)
        channel.setMethodCallHandler(this)
        context = flutterPluginBinding.applicationContext
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
        context = null
        ackit = null
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "setup" -> setup(call, result)
            "presentNotice" -> presentNotice(call, result)
            "clearConsent" -> clearConsent(result)
            "checkForUpdate" -> checkForUpdate(result)
            "isSubjectToGDPR" -> isSubjectToGDPR(result)
            "consentGiven" -> consentGiven(result)
            "geolocationConsentGiven" -> geolocationConsentGiven(result)
            "consentableAllowed" -> consentableAllowed(call, result)
            else -> {
                result.notImplemented()
            }
        }
    }

    private fun onReady(appConsent: AppConsentImpl, result: Result) {
        result.success(null)
    }

    private fun setup(call: MethodCall, result: Result) {
        if (context == null) {
            result.error(
                "SFBX_ERROR_NO_CONTEXT",
                "No Android context present, unable to setup AppConsent module.",
                null
            )
        } else {
            context?.let {
                val appKey: String = call.argument("appKey") ?: ""
                val forceApplyGDPR: Boolean = call.argument("forceApplyGDPR") ?: false

                ackit = AppConsentTV(
                    context = it,
                    appKey = appKey,
                    forceApplyGDPR = forceApplyGDPR, onReady = { (this::onReady)(it, result) })
            }
        }
    }

    private fun presentNotice(call: MethodCall, result: Result) {
        val force: Boolean = call.argument("force") ?: false
        ackit?.presentNotice(force)
        result.success(null)
    }

    private fun clearConsent(result: Result) {
        ackit?.clearConsent()
        result.success(null)
    }

    private fun checkForUpdate(result: Result) {
        ackit?.checkForUpdate(onResult = {
            result.success(it)
        },
            error = {
                result.success(false)
            })
    }

    private fun isSubjectToGDPR(result: Result) {
        val isSubjectToGDPR = ackit?.isSubjectToGDPR()
        result.success(isSubjectToGDPR)
    }

    private fun consentGiven(result: Result) {
        val consentGiven = ackit?.consentGiven()
        result.success(consentGiven)
    }

    private fun geolocationConsentGiven(result: Result) {
        val geolocationConsentGiven = ackit?.geolocationConsentGiven()
        result.success(geolocationConsentGiven)
    }

    private fun consentableAllowed(call: MethodCall, result: Result) {
        val iabId: Int = call.argument("iabId") ?: 0
        val type: Int = call.argument("consentableType") ?: 0
        val consentableType: ConsentableType = when (type) {
            0 -> ConsentableType.PURPOSE
            1 -> ConsentableType.FEATURE
            2 -> ConsentableType.SPECIAL_FEATURE
            3 -> ConsentableType.SPECIAL_PURPOSE
            else -> ConsentableType.UNKNOWN
        }
        val isAllowed = ackit?.consentableAllowed(iabId, consentableType)
        result.success(isAllowed)
    }

    companion object {
        private val channelName = "appconsent_tv"
    }
}
